@@ -12,9 +12,18 @@
 #include "vec2.h"
 #include "vec3.h"
 #include "vec4.h"
+#include "ivec2.h"
+#include "ivec3.h"
+#include "ivec4.h"
 #include "mat4.h"
+#include "mat4x2.h"
+#include "mat4x3.h"
 #include "mat3.h"
+#include "mat3x2.h"
+#include "mat3x4.h"
 #include "mat2.h"
+#include "mat2x3.h"
+#include "mat2x4.h"
 #include "affine.h"
 #include "cam.h"
 #include "frustum.h"
